@@ -1,33 +1,67 @@
 import os
+import random
+import urllib.parse
 from .utils import random_key, build_get_url, get_req_json, get_req_content, get_req_text
 from .tiktok_browser import TikTokBrowser
 
 
 class TikTokAPI(object):
 
-    def __init__(self, language='en', region='IN', cookie=None):
+    def __init__(self, language='en', browser_lang="en-US", timezone="Asia/Kolkata", region='IN', cookie=None):
         self.base_url = "https://t.tiktok.com/api"
-        self.user_agent = "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_5) AppleWebKit/537.36 (KHTML, like Gecko) " \
-                          "Chrome/83.0.4103.106 Safari/537.36"
+        self.user_agent = "Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:79.0) Gecko/20100101 Firefox/79.0"
 
         self.headers = {
-            "User-Agent": self.user_agent
+            "User-Agent": self.user_agent,
         }
         self.language = language
+        self.browser_lang = browser_lang
+        self.timezone = timezone
         self.region = region
+
         if cookie is None:
             self.verifyFp = random_key(16)
         else:
             self.verifyFp = cookie
         self.default_params = {
+            "aid": "1988",
+            "app_name": "tiktok_web",
+            "device_platform": "web",
+            "referer": "",
+            "user_agent": urllib.parse.quote_plus(self.user_agent),
+            "cookie_enabled": "true",
+            "screen_width": "1920",
+            "screen_height": "1080",
+            "browser_language": self.browser_lang,
+            "browser_platform": "Linux+x86_64",
+            "browser_name": "Mozilla",
+            "browser_version": "5.0+(X11)",
+            "browser_online": "true",
+            "timezone_name": self.timezone,
+            # "page_referer": "https://www.tiktok.com/foryou?lang=en",
+            "priority_region": self.region,
+
+            "appId": "1180",
+            "region": self.region,
+            "appType": "t",
+
+            "isAndroid": "false",
+            "isMobile": "false",
+            "isIOS": "false",
+            "OS": "linux",
+            "tt-web-region": self.region,
+
             "language": self.language,
             "verifyFp": self.verifyFp
         }
         self.signature_key = "_signature"
+        self.did_key = "did"
         self.tiktok_browser = TikTokBrowser(self.user_agent)
 
     def send_get_request(self, url, params, extra_headers=None):
         url = build_get_url(url, params)
+        did = str(random.randint(10000, 999999999))
+        url = build_get_url(url, {self.did_key: did}, append=True)
         signature = self.tiktok_browser.fetch_auth_params(url, language=self.language)
         url = build_get_url(url, {self.signature_key: signature}, append=True)
         if extra_headers is None:
@@ -45,13 +79,11 @@ class TikTokAPI(object):
         url = self.base_url + "/item_list/"
         req_default_params = {
             "id": "1",
-            "type": "1",
+            "type": "5",
             "secUid": "",
             "maxCursor": "0",
             "minCursor": "0",
             "sourceType": "12",
-            "appId": "1180",
-            "region": self.region
         }
         params = {
             "count": str(count)
@@ -83,8 +115,6 @@ class TikTokAPI(object):
             "maxCursor": "0",
             "minCursor": "0",
             "sourceType": "8",
-            "appId": "1180",
-            "region": self.region
         }
         params = {
             "id": user_id,
@@ -109,8 +139,6 @@ class TikTokAPI(object):
             "maxCursor": "0",
             "minCursor": "0",
             "sourceType": "9",
-            "appId": "1180",
-            "region": self.region
         }
         params = {
             "id": user_id,
